@@ -1,7 +1,9 @@
 #[derive(Debug, thiserror::Error)]
 pub enum Error {
     #[error("error while parsin json: {0}")]
-    Parser(#[from] serde_json::Error),
+    JsonParser(#[from] serde_json::Error),
+    #[error("error while parsin xml: {0}")]
+    XMLParser(#[from] serde_xml_rs::Error),
     #[error("error with the http connection: {0}")]
     HttpClient(#[from] hyper::Error),
     #[error("error with http: {0}")]
