@@ -9,9 +9,10 @@ mod client;
 pub mod error;
 #[macro_use]
 mod macros;
+pub mod legacy;
 pub mod player_service;
 pub mod steam_apps;
-mod steam_id;
+pub mod steam_id;
 pub mod steam_news;
 pub mod steam_user;
 pub mod steam_user_stats;
