@@ -4,8 +4,7 @@ use crate::client::SteamClient;
 use crate::error::Error;
 use crate::steam_id::SteamID;
 use crate::utils::{
-    bool_from_int_maybe_missing, concat_steam_ids, PlayersWrapper, ResponseWrapper, Result,
-    AUTHORITY,
+    bool_from_int_maybe_missing, PlayersWrapper, ResponseWrapper, Result, AUTHORITY,
 };
 use hyper::body::to_bytes;
 use hyper::Uri;
@@ -76,7 +75,7 @@ pub struct Summary {
     pub profile_name: String,
     /// Unix timestamp of users last logoff
     #[serde(rename = "lastlogoff")]
-    pub last_logoff: u64,
+    pub last_logoff: u32,
     #[serde(rename = "profileurl")]
     pub profile_url: String,
     /// 32x32 pixel image
@@ -96,11 +95,11 @@ pub struct Summary {
     pub primaryclanid: Option<SteamID>,
     /// Unix timestamp of users creation
     #[serde(rename = "timecreated")]
-    pub time_created: Option<u64>,
+    pub time_created: Option<u32>,
     #[serde(rename = "loccountrycode")]
     pub country_code: Option<String>,
     #[serde(rename = "loccityid")]
-    pub city_id: Option<u64>,
+    pub city_id: Option<u32>,
     #[serde(rename = "gameid")]
     pub game_id: Option<String>,
     #[serde(rename = "gameextrainfo")]
@@ -120,7 +119,7 @@ impl SteamClient {
     /// just drops the summary from the response. So don't assume the returned
     /// [Summaries](Summary) are in the same order as the [SteamIDs](SteamID).
     /// Always check the [SteamID] from the [Summary] struct.
-    pub async fn get_player_summaries(&self, ids: Vec<SteamID>) -> Result<Vec<Summary>> {
+    pub async fn get_player_summaries(&self, ids: &Vec<SteamID>) -> Result<Vec<Summary>> {
         let api_key = self
             .api_key
             .as_ref()
@@ -129,7 +128,11 @@ impl SteamClient {
         if ids.len() > 100 {
             return Err(Error::client("too many IDs (> 100)"));
         }
-        let id_query = concat_steam_ids(ids);
+        let id_query = ids
+            .iter()
+            .map(|id| id.to_string())
+            .collect::<Vec<String>>()
+            .join(",");
         let query = format!("key={}&steamids={}", api_key, id_query);
         let uri = Uri::builder()
             .scheme("https")
@@ -154,7 +157,7 @@ mod tests {
     fn works_with_single() {
         let client = SteamClient::with_api_key(&env::var("STEAM_API_KEY").unwrap());
         let summary = tokio_test::block_on(
-            client.get_player_summaries(vec![SteamID::from(76561198061271782)]),
+            client.get_player_summaries(&vec![SteamID::from(76561198061271782)]),
         )
         .unwrap();
         println!("{:?}", summary);
@@ -164,7 +167,7 @@ mod tests {
     #[test]
     fn works_with_multiple() {
         let client = SteamClient::with_api_key(&env::var("STEAM_API_KEY").unwrap());
-        let summary = tokio_test::block_on(client.get_player_summaries(vec![
+        let summary = tokio_test::block_on(client.get_player_summaries(&vec![
             SteamID::from(76561198061271782),
             SteamID::from(76561198072766352),
         ]))
@@ -176,7 +179,7 @@ mod tests {
     fn works_with_invalid() {
         let client = SteamClient::with_api_key(&env::var("STEAM_API_KEY").unwrap());
         let summary = tokio_test::block_on(
-            client.get_player_summaries(vec![SteamID::from(7656119806127178)]),
+            client.get_player_summaries(&vec![SteamID::from(7656119806127178)]),
         )
         .unwrap();
         assert!(summary.is_empty());
